/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Adblock Plus Code
 *
 * ***** END LICENSE BLOCK ***** */

var listBox;
var urlList;


//start-finish functions

function init() 
{
    var Branch = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("adblock.");
    var hideGlobal = Branch.getBoolPref("hideglobal");
    var hideEnabled = Branch.getBoolPref("hideenabled");
    urlList = Branch.getCharPref("hidelist");
    
    document.getElementById("hide-global").setAttribute("checked",hideGlobal);
    document.getElementById("hide-enabled").setAttribute("checked",hideEnabled);
    listBox  = document.getElementById("listBox");
    populateListBox();
    toggleEnabled();
}

function save() 
{
    var Branch = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("adblock.");
    var listSort = Branch.getBoolPref("listsort");
    
    var hideGlobal = document.getElementById("hide-global");
    Branch.setBoolPref("hideglobal", (hideGlobal.getAttribute("checked") == "true") ? true:false);
    
    var hideEnabled = document.getElementById("hide-enabled");
    Branch.setBoolPref("hideenabled", (hideEnabled.getAttribute("checked") == "true") ? true:false);
    
    //sort list before saving
    if (listSort) {
        var sites = urlList.split(" ");
        sites.sort();
        urlList = sites.join(" ");;
    }
    
    Branch.setCharPref("hidelist", urlList);
    
    window.close();
}


//listbox functions

function populateListBox() 
{
    var sites = urlList.split(" ");
    
    //remove existing list
    for (var i=listBox.getRowCount()-1; i>=0; i--)
        listBox.removeItemAt(i);
    
    //append list
    for (var j=0; j<sites.length; j++)
        listBox.appendItem(sites[j],sites[j]);
    
}

function urlChanged() 
{
    var urlText = document.getElementById("urlText");
    var url = urlText.value;
    var sites = urlList.split(" ");
    var match = false;
    
    //prevent spaces
    if(url.match(/\s/)) url = urlText.value=url.replace(/\s/g,'');
    
    for (var i=0; i<sites.length && sites!=""; i++)
        if (url.indexOf(sites[i]) != -1) match = true;
    
    if (url.length > 0 && !match)
        document.getElementById("addButton").setAttribute("disabled",false);
    else
        document.getElementById("addButton").setAttribute("disabled",true);
}

function addSite() 
{
    var urlText = document.getElementById("urlText");
    var site = urlText.value;
    urlText.value = "";
    document.getElementById("addButton").setAttribute("disabled",true);
    
    
    if (urlList.length == 0) urlList = site;
    else urlList += " " + site;
    
    focusTextBox();
    populateListBox();
    listBox.ensureIndexIsVisible(listBox.getRowCount()-1);
}

function getCurrentSite() 
{
    var site = window.opener.opener.content.location.href;
    
    // Don't get domain if not an http site
    if (/^https?:\/\//.test(site) == false)
        return null;

    // Extract domain
    var dom = /\/\/[^\/]+\//;
    site = dom.exec(site)[0];
    
    // Remove matched '/' and 'www.'
    if (/www\./.test(site))
        site = site.slice(6,site.length-1);
    else
        site = site.slice(2,site.length-1);

    return site;
}

function addCurrentSite() 
{
    
    var site = getCurrentSite();
    
    focusTextBox();
    if (site == null) return;

    // Add to hide url list
    if (urlList.length == 0) urlList = site;
    else urlList += " " + site;
    
    populateListBox();
    listBox.ensureIndexIsVisible(listBox.getRowCount()-1);
    document.getElementById("addCurrentButton").setAttribute("disabled",true);
}

function urlCheck() 
{
    var url = getCurrentSite();
    var match = urlList.indexOf(url) != -1;
    
    document.getElementById("addCurrentButton").setAttribute("disabled", match);
}

function toggleEnabled()
{
    var checked = (document.getElementById("hide-enabled").getAttribute("checked") == "true") ? true:false;
    
    if (checked)
    {
        document.getElementById("enabledState").removeAttribute("disabled");
        document.getElementById("hide-global").removeAttribute("disabled");
        urlCheck();
        toggleGlobalAccess();
    }
    else
    {
        document.getElementById("enabledState").setAttribute("disabled", "true");
        document.getElementById("hide-global").setAttribute("disabled", "true");
    }
}

function toggleGlobalAccess()
{
    var checked = (document.getElementById("hide-global").getAttribute("checked") == "true") ? true:false;
    
    //need to remove disabled attribute instead of setting it to false otherwise textbox can't receive input
    if (checked)
        document.getElementById("enabledState").setAttribute("disabled", "true");
    else
        document.getElementById("enabledState").removeAttribute("disabled");
}

function removeAll() 
{
    urlList = "";
    populateListBox();
    focusTextBox();
    document.getElementById("addCurrentButton").setAttribute("disabled",false);
}

function remove() 
{
    var selectedIndex = listBox.selectedIndex;
    var listitem;
    urlList = "";
    
    for (var i=listBox.getRowCount()-1; i >= 0; i--)
    {
        listitem =  listBox.getItemAtIndex(i);
        
        if (listitem.selected)
            listBox.removeItemAt(i);
        else if (urlList.length == 0)
            urlList = listitem.value;
        else
            urlList += " " + listitem.value;
    }
    
    selectedIndex = (selectedIndex >= listBox.getRowCount()) ? listBox.getRowCount()-1 : selectedIndex;
    listBox.selectedIndex = selectedIndex;
    
    if (selectedIndex != -1)
        listBox.ensureIndexIsVisible(selectedIndex);
}

function focusTextBox()
{
    document.getElementById("urlText").focus();
}


//IO functions
function importSites()
{
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(Components.interfaces.nsIFilePicker);
    var stream = Components.classes["@mozilla.org/network/file-input-stream;1"].createInstance(Components.interfaces.nsIFileInputStream);
    var streamIO = Components.classes["@mozilla.org/scriptableinputstream;1"].createInstance(Components.interfaces.nsIScriptableInputStream);
    var linebreak, input, inputArray;
    
    fp.init(window, document.getElementById("bundle_adblock").getString("adblock.selectafile"), fp.modeOpen);
    fp.appendFilters(fp.filterText);

    if (fp.show() != fp.returnCancel) {
        stream.init(fp.file, 0x01, 0444, null);
        streamIO.init(stream);
        input = streamIO.read(stream.available());
        streamIO.close();
        stream.close();
        
        linebreak = input.match(/(((\n+)|(\r+))+)/m);
        inputArray = (linebreak != null) ? input.split(linebreak[1]) : input;
        
        var headerRe = /\[Adblock Hide List\]/i;
        if (headerRe.test(inputArray[0]))
        {
            inputArray.shift();
            result = attachFilters(inputArray, document.getElementById("bundle_adblock").getString("adblock.importsites"), true);
            if (result == undefined) return;
            else urlList = result.join(" ");
            populateListBox();
        }
        else
        {
            var path = fp.fileURL.fileName;
            var slashIndex = (path.lastIndexOf('/'))+1;
            var filterFile = (slashIndex >= path.length) ? "" : path.slice(slashIndex, path.length);
            alert(document.getElementById("bundle_adblock").getString("adblock.invalidsitefile") + " " + filterFile);
            return;
        }
    }
}


function exportSites()
{
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(Components.interfaces.nsIFilePicker);
    var stream = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance(Components.interfaces.nsIFileOutputStream);
    
    fp.init(window, document.getElementById("bundle_adblock").getString("adblock.saveas"), fp.modeSave);
    fp.defaultExtension=".txt";
    
    fp.appendFilters(fp.filterText);

    if (fp.show() != fp.returnCancel)
    {
        if (fp.file.exists())
            fp.file.remove(true);
        fp.file.create(fp.file.NORMAL_FILE_TYPE, 0666);
        
        stream.init(fp.file, 0x02, 0x200, null);
        stream.write("[Adblock Hide List]" + linebreak.string(), 19 + linebreak.length());
        
        var sites = urlList.split(" ");
        
         for (var i = 0; i < sites.length ; i++)
        {
            stream.write(sites[i], sites[i].length);
            stream.write(linebreak.string(), linebreak.length());
        }
        stream.close();
    }
}

